goffice r2210 - in branches/goffice-0-6: . goffice/utils



Author: mortenw
Date: Thu Sep  4 20:34:16 2008
New Revision: 2210
URL: http://svn.gnome.org/viewvc/goffice?rev=2210&view=rev

Log:
Morten:
	* Fix go_url_resolve_relative.  [#550898]



Modified:
   branches/goffice-0-6/ChangeLog
   branches/goffice-0-6/NEWS
   branches/goffice-0-6/goffice/utils/go-file.c

Modified: branches/goffice-0-6/NEWS
==============================================================================
--- branches/goffice-0-6/NEWS	(original)
+++ branches/goffice-0-6/NEWS	Thu Sep  4 20:34:16 2008
@@ -1,3 +1,12 @@
+goffice 0.6.6:
+
+Morten:
+	* Fix go_url_resolve_relative.  [#550898]
+
+--------------------------------------------------------------------------
+goffice 0.6.5:
+
+--------------------------------------------------------------------------
 goffice 0.6.4:
 
 Jean:

Modified: branches/goffice-0-6/goffice/utils/go-file.c
==============================================================================
--- branches/goffice-0-6/goffice/utils/go-file.c	(original)
+++ branches/goffice-0-6/goffice/utils/go-file.c	Thu Sep  4 20:34:16 2008
@@ -301,10 +301,10 @@
 
 	len = strlen (ref_uri);
 
 	/* FIXME: This doesn't work if rel_uri starts with a slash.  */
 
 	uri = g_new (char, len + strlen (rel_uri) + 1);
-	memcpy (uri, rel_uri, len + 1);
+	memcpy (uri, ref_uri, len + 1);
 	while (len > 0 && uri[len - 1] != '/')
 		len--;
 	if (len == 0) {
@@ -301,10 +301,10 @@
 	len = strlen (ref_uri);
 
-	/* FIXME: This doesn't work if rel_uri starts with a slash.  */
+	/* FIXME: This doesn't work if ref_uri starts with a slash.  */
 
 	uri = g_new (char, len + strlen (rel_uri) + 1);



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]